package com.xubx.springboot_01demo.controller;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.xubx.springboot_01demo.pojo.Relationship;
import com.xubx.springboot_01demo.pojo.User;
import com.xubx.springboot_01demo.service.UserService;
import com.xubx.springboot_01demo.utils.api.Result;
import com.xubx.springboot_01demo.utils.token.RedisUtil;
import com.xubx.springboot_01demo.utils.token.RequestHolder;
import com.xubx.springboot_01demo.utils.token.TokenGenerate;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpSession;
import java.io.File;
import java.io.IOException;
import java.util.List;

@RestController //注解标识这是一个控制器类
@CrossOrigin    //加上CrossOrigin可解决跨域问题
@Slf4j
@Api(tags = "用户接口")
@RequestMapping("/user")
public class UserController {
    @Resource
    UserService userService;
    @Resource
    RedisUtil redisUtil;
    //    注入session
    @Resource
    private HttpSession session;

    /**
     * 用户注册
     *
     * @param user
     * @return
     */
    @PostMapping("/register")
    @ApiOperation("用户注册")
    public ResponseEntity<String> register(@RequestBody User user) {
        // 输入验证
        if (user.getUsername() == null || user.getUsername().isEmpty()) {
            return ResponseEntity.badRequest().body("用户名不能为空");
        }
        if (user.getPassword() == null || user.getPassword().isEmpty()) {
            return ResponseEntity.badRequest().body("密码不能为空");
        }
        try {
            if (userService.insertUser(user)) {
                return ResponseEntity.status(HttpStatus.CREATED).body("注册成功");
            } else {
                return ResponseEntity.status(HttpStatus.CONFLICT).body("用户已经存在");
            }
        } catch (Exception e) {
            // 异常处理
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body("注册失败，服务器内部错误");
        }
    }

    /**
     * 用户登录
     *
     * @param user
     * @return
     */
    @PostMapping("/login")
    @ApiOperation("用户登录")
    public String login(@RequestBody User user) {
        log.info("用户登录:{}", user.getUsername());
        //登陆
        if (userService.findUserByUsername(user)) {
            String token = new TokenGenerate().generateToken(user.getUsername());
            //将username存入session
            session.setAttribute("username", user.getUsername());
            redisUtil.addTokens(user.getUsername(), token);
            return token;
        }
        return "false";
    }

    /**
     * 获取用户名
     *
     * @return
     */
    @GetMapping("/getUsername")
    @ApiOperation("获取用户名")
    public String getUserName() {
        return RequestHolder.getuserId();
    }

    /**
     * 退出登录
     *
     * @return
     */
    @RequestMapping("/uploadAvatar")
    @ApiOperation("上传头像")
    public void uploadAvatar(MultipartFile file) throws IOException {
        String pType = file.getContentType();
        pType = pType.substring(pType.indexOf("/") + 1);
        if ("jpeg".equals(pType)) {
            pType = "jpg";
        }
        long time = System.currentTimeMillis();
        String currentWorkingDirectory = System.getProperty("user.dir");
        String relativePath = "/images/avatar/" + time + "." + pType;
        String absolutePath = currentWorkingDirectory + "/static" + relativePath;
        file.transferTo(new File(absolutePath));
        System.out.println("导入数据库的路径：" + relativePath + "当前用户：" + RequestHolder.getuserId());
        userService.addAvatar(relativePath, RequestHolder.getuserId());
    }

    /**
     * 获取头像
     *
     * @return
     */
    @GetMapping("/getAvatar")
    @ApiOperation("获取头像")
    public String getAvatar() {
        String path = userService.getAvatar(RequestHolder.getuserId());
        System.out.println("发给前端的路径:" + path);
        return path;
    }

    /**
     * 修改用户名
     *
     * @param username
     * @return
     */
    @GetMapping("usernameChange")
    @ApiOperation("修改用户名")
    public ResponseEntity<String> usernameChange(@RequestParam("username") String username) {
        if (userService.usernameChange(RequestHolder.getuserId(), username)) {
            RequestHolder.add(username);
            return ResponseEntity.ok("修改成功！");
        }
        return ResponseEntity.ok("该用户已存在！");
    }

    /**
     * 修改密码
     *
     * @param oldPassword
     * @param newPassword
     * @return
     */
    @GetMapping("passwordChange")
    @ApiOperation("修改密码")
    public ResponseEntity<String> passwordChange(@RequestParam("oldPassword") String oldPassword, @RequestParam("newPassword") String newPassword) {
        if (userService.passwordChange(RequestHolder.getuserId(), oldPassword, newPassword)) {
            return ResponseEntity.ok("修改成功！");
        }
        return ResponseEntity.ok("原密码输入错误！");
    }

    /**
     * 查看是否有好友请求
     *
     * @return
     */
    @GetMapping("/checkFriendRequest")
    public JSONObject haveFriendRequest() {
        return userService.checkFriendRequest(RequestHolder.getuserId());
    }
}
