package com.xubx.springboot_01demo.service.impl;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.xubx.springboot_01demo.mapper.RelationshipMapper;
import com.xubx.springboot_01demo.mapper.UserMapper;
import com.xubx.springboot_01demo.pojo.Relationship;
import com.xubx.springboot_01demo.pojo.User;
import com.xubx.springboot_01demo.service.UserService;
import com.xubx.springboot_01demo.utils.api.Result;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;

//Service进行具体的业务处理
@Service
public class UserServiceImpl implements UserService {
    @Resource
    UserMapper userMapper;
    @Resource
    RelationshipMapper relationshipMapper;

    //登陆，获取User对象
    @Override
    public Boolean findUserByUsername(User user) {
        try {
            User userByUsername = userMapper.findUserByUsername(user.getUsername());

            if (Objects.equals(userByUsername.getPassword(), user.getPassword())) {
                return true;
            }
            return false;
        } catch (Exception e) {
            System.out.println(e);
            return false;
        }
    }

    //注册，新增
    @Override
    public Boolean insertUser(User user) {
        // 检查用户名是否已存在
        if (userMapper.findUserByUsername(user.getUsername()) != null) {
            return false;
        }
        // 用户名不存在,插入新用户
        userMapper.insertUser(user);
        return true;
    }

    @Override
    public void addAvatar(String path, String username) {
        userMapper.addAvatar(path, username);
    }

    @Override
    public String getAvatar(String name) {
        return userMapper.getAvatar(name);
    }

    @Override
    public boolean usernameChange(String usernameNow, String username) {
        // 检查用户名是否已存在
        if (userMapper.findUserByUsername(username) != null) {
            return false;
        }
        userMapper.usernameChange(usernameNow, username);
        return true;
    }

    @Override
    public boolean passwordChange(String username, String oldPassword, String newPassword) {
        //检查输入的原密码是否正确
        if (oldPassword.equals(userMapper.getPasswordByname(username))) {
            userMapper.passwordChange(username, newPassword);
            return true;
        }
        return false;
    }

    //查看是否有好友请求
    @Override
    public JSONObject checkFriendRequest(String getuserId) {
        List<Relationship> relationships = relationshipMapper.checkFriendRequest(getuserId);
        JSONArray jsonArray = new JSONArray();
        for (Relationship relationship : relationships) {
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("id", relationship.getId());
            jsonObject.put("username", relationship.getUsername());
            jsonObject.put("friend", relationship.getFriend());
            jsonObject.put("created", relationship.getCreated().toString());
            jsonObject.put("initiator", relationship.getInitiator());
            jsonObject.put("avatar", userMapper.getAvatar(relationship.getInitiator()));
            jsonArray.add(jsonObject);
        }
        JSONObject result = new JSONObject();
        result.put("friendRequests", jsonArray);
        return result;
    }
}
